package CSS::Croco::Statement::RuleSet;
@ISA = qw(CSS::Croco::Statement);
use utf8;
use strict;
use warnings;

=head1 NAME

<+name+>

=head1 DESCRIPTION



=head1 BUGS

=head1 NOTES

=head1 AUTHOR

Andrey Kostenko (), <andrey@kostenko.name>

=head1 COMPANY

Rambler Internet Holding

=head1 CREATED

02.11.2009 02:15:11 MSK

=cut

1;

